==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/net.fortuna.ical4j/src/net/fortuna/ical4j/util/Numbers.java <==
/**
 * Copyright (c) 2012, Ben Fortuna
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  o Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 *  o Neither the name of Ben Fortuna nor the names of any other contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.fortuna.ical4j.util;

/**
 * $Id$
 *
 * Created on 6/08/2005
 *
 * A utility class for number processing.
 * @author Ben Fortuna
 */
public final class Numbers {

    /**
     * Constructor made private to enforce static nature.
     */
    private Numbers() {
    }
    
    /**
     * Wraps <code>java.lang.Integer.parseInt()</code> to accept values with
     * a PLUS character (i.e. "+2").
     * @param value an integer string
     * @return a parsed integer value
     */
    public static int parseInt(final String value) {
        if (value != null && value.charAt(0) == '+') {
            return Integer.parseInt(value.substring(1));
        }
        return Integer.parseInt(value);
    }
}

==> open-xchange-core_7.10.3.orig.tar.bz2: open-xchange-core-7.10.3/net.fortuna.ical4j/src/net/fortuna/ical4j/util/Numbers.java <==
/**
 * Copyright (c) 2012, Ben Fortuna
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  o Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 *  o Neither the name of Ben Fortuna nor the names of any other contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.fortuna.ical4j.util;

/**
 * $Id$
 *
 * Created on 6/08/2005
 *
 * A utility class for number processing.
 * @author Ben Fortuna
 */
public final class Numbers {

    /**
     * Constructor made private to enforce static nature.
     */
    private Numbers() {
    }

    /**
     * Wraps <code>java.lang.Integer.parseInt()</code> to accept values with
     * a PLUS character (i.e. "+2").
     * @param value an integer string
     * @return a parsed integer value
     */
    public static int parseInt(final String value) {
        if (null == value) {
            throw new NumberFormatException("null");
        }
        if (value.length() <= 0) {
            throw new NumberFormatException("empty string");
        }
        return value.charAt(0) == '+' ? Integer.parseInt(value.substring(1)) : Integer.parseInt(value);
    }
}
